---
title: mosquitto
type: docs
---

[![Source Code](https://img.shields.io/badge/gitea-source%20code-blue?logo=gitea&logoColor=white)](https://gitea.rknet.org/ansible/xoxys.mosquitto) [![Build Status](https://img.shields.io/drone/build/ansible/xoxys.mosquitto?logo=drone&server=https%3A%2F%2Fdrone.rknet.org)](https://drone.rknet.org/ansible/xoxys.mosquitto) [![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/ansible/xoxys.mosquitto/src/branch/main/LICENSE)

Setup [mosquitto](https://mosquitto.org/) mqtt broker. Eclipse Mosquitto is a message broker that implements the MQTT protocol. It is lightweight and suitable for use on all devices from low power single board computers to full servers.

<!--more-->

- [Default Variables](#default-variables)
  - [mosquitto_acl](#mosquitto_acl)
  - [mosquitto_acl_enabled](#mosquitto_acl_enabled)
  - [mosquitto_acl_file](#mosquitto_acl_file)
  - [mosquitto_base_dir](#mosquitto_base_dir)
  - [mosquitto_bind_address](#mosquitto_bind_address)
  - [mosquitto_ca_path](#mosquitto_ca_path)
  - [mosquitto_group](#mosquitto_group)
  - [mosquitto_packages_extra](#mosquitto_packages_extra)
  - [mosquitto_password_auth_enabled](#mosquitto_password_auth_enabled)
  - [mosquitto_password_auth_file](#mosquitto_password_auth_file)
  - [mosquitto_password_auth_users](#mosquitto_password_auth_users)
  - [mosquitto_persistence_enabled](#mosquitto_persistence_enabled)
  - [mosquitto_persistence_path](#mosquitto_persistence_path)
  - [mosquitto_pid_file](#mosquitto_pid_file)
  - [mosquitto_port](#mosquitto_port)
  - [mosquitto_tls_cert_path](#mosquitto_tls_cert_path)
  - [mosquitto_tls_cert_source](#mosquitto_tls_cert_source)
  - [mosquitto_tls_ciphers](#mosquitto_tls_ciphers)
  - [mosquitto_tls_enabled](#mosquitto_tls_enabled)
  - [mosquitto_tls_key_path](#mosquitto_tls_key_path)
  - [mosquitto_tls_key_source](#mosquitto_tls_key_source)
  - [mosquitto_user](#mosquitto_user)
- [Discovered Tags](#discovered-tags)
- [Dependencies](#dependencies)

---

## Default Variables

### mosquitto_acl

#### Default value

```YAML
mosquitto_acl: []
```

#### Example usage

```YAML
mosquitto_acl:
  - name: iot
    user: admin
    acls:
      - acl_base: topic # (topic|pattern, defaults to topic)
        acl_topic: "#"
        acl_policy: readwrite
  - name: readonly_iot
    user: user1
    acls:
      - acl_base: topic
        acl_topic: my/devices
        acl_policy: readwrite
```

### mosquitto_acl_enabled

#### Default value

```YAML
mosquitto_acl_enabled: false
```

### mosquitto_acl_file

#### Default value

```YAML
mosquitto_acl_file: '{{ mosquitto_base_dir }}/aclfile'
```

### mosquitto_base_dir

#### Default value

```YAML
mosquitto_base_dir: /etc/mosquitto
```

### mosquitto_bind_address

#### Default value

```YAML
mosquitto_bind_address: '{{ ansible_default_ipv4.address }}'
```

### mosquitto_ca_path

#### Default value

```YAML
mosquitto_ca_path: /etc/pki/tls/certs/
```

### mosquitto_group

#### Default value

```YAML
mosquitto_group: mosquitto
```

### mosquitto_packages_extra

#### Default value

```YAML
mosquitto_packages_extra: []
```

### mosquitto_password_auth_enabled

#### Default value

```YAML
mosquitto_password_auth_enabled: false
```

### mosquitto_password_auth_file

#### Default value

```YAML
mosquitto_password_auth_file: '{{ mosquitto_base_dir }}/passwd'
```

### mosquitto_password_auth_users

#### Default value

```YAML
mosquitto_password_auth_users: []
```

#### Example usage

```YAML
mosquitto_password_auth_users:
  - name: admin
    password: mysecret
    state: present
  - name: user1
    password: very_secure
    state: absent
```

### mosquitto_persistence_enabled

#### Default value

```YAML
mosquitto_persistence_enabled: false
```

### mosquitto_persistence_path

#### Default value

```YAML
mosquitto_persistence_path: /var/lib/mosquitto/mosquitto.db
```

### mosquitto_pid_file

#### Default value

```YAML
mosquitto_pid_file: /var/run/mosquitto.pid
```

### mosquitto_port

#### Default value

```YAML
mosquitto_port: 1883
```

### mosquitto_tls_cert_path

#### Default value

```YAML
mosquitto_tls_cert_path: '{{ mosquitto_base_dir }}/tls/certs/mycert.pem'
```

### mosquitto_tls_cert_source

#### Default value

```YAML
mosquitto_tls_cert_source: mycert.pem
```

### mosquitto_tls_ciphers

#### Default value

```YAML
mosquitto_tls_ciphers:
  - DEFAULT
  - '!aNULL'
  - '!eNULL'
  - '!LOW'
  - '!EXPORT'
  - '!SSLv2'
  - '@STRENGTH'
```

### mosquitto_tls_enabled

#### Default value

```YAML
mosquitto_tls_enabled: false
```

### mosquitto_tls_key_path

#### Default value

```YAML
mosquitto_tls_key_path: '{{ mosquitto_base_dir }}/tls/private/mykey.pem'
```

### mosquitto_tls_key_source

#### Default value

```YAML
mosquitto_tls_key_source: mykey.pem
```

### mosquitto_user

#### Default value

```YAML
mosquitto_user: mosquitto
```

## Discovered Tags

tls_renewal
: &nbsp;


## Dependencies

None.
